==> 4.0.1.tar.gz: dde-dock/translations/dde-dock_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="73"/>
        <source>MM/dd/yyyy ddd HH:mm:ss</source>
        <translation>MM/dd/yyyy ddd HH:mm:ss</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <location filename="../plugins/datetime/datetimewidget.cpp" line="35"/>
        <source>HH:mm</source>
        <translation>HH:mm</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="82"/>
        <source>Unknown device</source>
        <translation>未知的设备</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="88"/>
        <source>Unknown volume</source>
        <translation>容量未知</translation>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="19"/>
        <source>Fashion Mode</source>
        <translation>时尚模式</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="20"/>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="21"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="22"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="23"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="24"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="25"/>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="26"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="27"/>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="28"/>
        <source>Keep Shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="29"/>
        <source>Keep Hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="30"/>
        <source>Smart Hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="64"/>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="72"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="79"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="86"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="17"/>
        <source>Launcher</source>
        <translation>启动器</translation>
    </message>
</context>
<context>
    <name>PopupControlWidget</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="70"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="70"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="75"/>
        <source>This action cannot be restored</source>
        <translation>此操作不可恢复</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="77"/>
        <source>Are you sure to empty 1 item ?</source>
        <translation>您确定要清空回收站里的1项内容吗？</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="79"/>
        <source>Are you sure to empty %1 items ?</source>
        <translation>您确定要清空回收站里的%1项内容吗？</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="28"/>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="47"/>
        <source>Application</source>
        <translation>应用</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="17"/>
        <source>Run</source>
        <translation>运行</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="18"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="36"/>
        <source>Unknow</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="41"/>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
</context>
<context>
    <name>WirelessApplet</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="35"/>
        <source>Auto-connect</source>
        <translation>自动连接</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="42"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="136"/>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="138"/>
        <source>Wireless Network %1</source>
        <translation>无线网络%1</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="367"/>
        <source>Password required to connect to &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;</source>
        <translation>连接&lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;需要密码</translation>
    </message>
</context>
</TS>

==> 4.0.2.tar.gz: dde-dock/translations/dde-dock_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>DatetimePlugin</name>
    <message>
        <location filename="../plugins/datetime/datetimeplugin.cpp" line="73"/>
        <source> HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <location filename="../plugins/datetime/datetimewidget.cpp" line="42"/>
        <source>HH:mm</source>
        <translation>HH:mm</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="86"/>
        <source>Unknown device</source>
        <translation>未知的设备</translation>
    </message>
    <message>
        <location filename="../plugins/disk-mount/diskcontrolitem.cpp" line="92"/>
        <source>Unknown volume</source>
        <translation>容量未知</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <location filename="../plugins/disk-mount/diskmountplugin.cpp" line="14"/>
        <source>Disk</source>
        <translation>磁盘</translation>
    </message>
</context>
<context>
    <name>DockSettings</name>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="20"/>
        <source>Fashion Mode</source>
        <translation>时尚模式</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="21"/>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="22"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="23"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="24"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="25"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="26"/>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="27"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="28"/>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="29"/>
        <source>Keep Shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="30"/>
        <source>Keep Hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="31"/>
        <source>Smart Hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="65"/>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="73"/>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="80"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../frame/util/docksettings.cpp" line="87"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <location filename="../frame/item/launcheritem.cpp" line="17"/>
        <source>Launcher</source>
        <translation>启动器</translation>
    </message>
</context>
<context>
    <name>PopupControlWidget</name>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="68"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="68"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="73"/>
        <source>This action cannot be restored</source>
        <translation>此操作不可恢复</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="75"/>
        <source>Are you sure to empty 1 item ?</source>
        <translation>您确定要清空回收站里的1项内容吗？</translation>
    </message>
    <message>
        <location filename="../plugins/trash/popupcontrolwidget.cpp" line="77"/>
        <source>Are you sure to empty %1 items ?</source>
        <translation>您确定要清空回收站里的%1项内容吗？</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <location filename="../plugins/shutdown/shutdownplugin.cpp" line="47"/>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="28"/>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../plugins/sound/soundapplet.cpp" line="47"/>
        <source>Application</source>
        <translation>应用</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="17"/>
        <source>Run</source>
        <translation>运行</translation>
    </message>
    <message>
        <location filename="../plugins/trash/trashwidget.cpp" line="18"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>WiredItem</name>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="36"/>
        <source>Unknow</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="41"/>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/wireditem.cpp" line="51"/>
        <source>Wired connection %1</source>
        <translation>有线连接%1</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="35"/>
        <source>Auto-connect</source>
        <translation>自动连接</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="42"/>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="43"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="143"/>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="145"/>
        <source>Wireless Network %1</source>
        <translation>无线网络%1</translation>
    </message>
    <message>
        <location filename="../plugins/network/item/applet/wirelessapplet.cpp" line="370"/>
        <source>Password required to connect to &lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;</source>
        <translation>连接&lt;font color=&quot;#faca57&quot;&gt;%1&lt;/font&gt;需要密码</translation>
    </message>
</context>
</TS>
